a list of purple air monitor IP addresses named according to their Sensor IDs
Arguments
network_prefix
character string; base IPv4 prefix
(first three octets) used to generate IP addresses
timeout
numeric; number of seconds to wait for each ping
Details
If the mirai package is available, this function will ensure that
at least version 1.1.0 of the purrr package is installed to scan the
network in parallel, according to mirai::daemons() set by the user.
This reduces the time it takes, but does not use a progress bar.