Stream the latest data from a sensor on the local area network.
Data is updated every second on the device; this function waits
half a second after each call, which takes less than half a second,
ensuring sub one second updating freqency.
Usage
local_sensor_live(ip_address)
Arguments
ip_address
address of purple air monitor on local area network
to request data from